/*
 * ar0330.c
 *
 *  Created on: Mar 09, 2016
 *      Author: Microsemi
 */
#include <stdio.h>
#include "ar0330.h"

extern gpio_instance_t g_gpio_out;

extern i2c_instance_t g_i2c_instance;
static i2c_instance_t * sensor_i2c = &g_i2c_instance;

static uint8_t tx_buffer[64];
//static uint8_t rx_buffer[64];
static uint32_t write_length;
static i2c_status_t status;

#define I2C_MUX_ADDR (0xE0 >> 1)

static i2c_status_t hdmi_i2c_tx_write(uint8_t i2c_div_address, uint8_t data_reg, uint8_t data)
{
	uint8_t write_length;
	i2c_status_t status;
	if(data_reg){
		tx_buffer[0] = data_reg;
		tx_buffer[1] = data;
		write_length = sizeof(data_reg) + sizeof(data);
	}else{
		tx_buffer[0] = data;
		write_length = sizeof(data);
	}

	I2C_write(sensor_i2c, i2c_div_address, (const uint8_t *)tx_buffer, write_length, I2C_RELEASE_BUS );

	status = I2C_wait_complete( sensor_i2c, I2C_NO_TIMEOUT );
	return status;
}


static i2c_status_t sensor_i2c_write(uint16_t data_reg, uint16_t data) {
	tx_buffer[0] = data_reg >> 8;
	tx_buffer[1] = data_reg & 0xff;
	tx_buffer[2] = data >> 8;
	tx_buffer[3] = data & 0xff;
	write_length = sizeof(data_reg) + sizeof(data);

	I2C_write(sensor_i2c, AR0331_DEV_REG, (const uint8_t *) tx_buffer,
			write_length, I2C_RELEASE_BUS );

	status = I2C_wait_complete(sensor_i2c, I2C_NO_TIMEOUT );
	return status;
}

static i2c_status_t sensor_i2c_read(uint16_t data_reg, uint16_t *data) {
	tx_buffer[0] = data_reg >> 8;
	tx_buffer[1] = data_reg & 0xff;
	write_length = sizeof(data_reg) + sizeof(data);

	I2C_write_read(sensor_i2c, AR0331_DEV_REG, tx_buffer, 2,
			(uint8_t *) data, 2, I2C_RELEASE_BUS );

	status = I2C_wait_complete(sensor_i2c, I2C_NO_TIMEOUT );
	return status;
}

static i2c_status_t sensor_i2c_write_bits(uint16_t data_reg, uint16_t mask,
		uint8_t bitval) {
	uint16_t readdata;
	uint16_t writedata;

	sensor_i2c_read(data_reg, (uint16_t *) &readdata);

	tx_buffer[0] = data_reg >> 8;
	tx_buffer[1] = data_reg & 0xff;

	if (bitval == 0) {
		writedata = readdata & ~mask;
	} else {
		writedata = readdata | mask;
	}
	tx_buffer[2] = writedata >> 8;
	tx_buffer[3] = writedata & 0xff;
	write_length = sizeof(data_reg) + sizeof(writedata);

	I2C_write(sensor_i2c, AR0331_DEV_REG, (const uint8_t *) tx_buffer,
			write_length, I2C_RELEASE_BUS );

	status = I2C_wait_complete(sensor_i2c, I2C_NO_TIMEOUT );
	return status;
}


static void mipi_pll_10bit_98mhz_1lane()
{

	sensor_i2c_write(0x302A, 0x0004 );  			// vt_pix_clk_div
	sensor_i2c_write(0x302C, 0x0001 );           // vt_sys_clk_div
	sensor_i2c_write(0x302E, 0x0002 );           // pre_pll_clk_div
	sensor_i2c_write(0x3030, 0x0019);           // pll_multiplier
	sensor_i2c_write(0x3036, 0x0008);           // op_pix_clk_div
	sensor_i2c_write(0x3038, 0x0001 );           // op_sys_clk_div

}

static void mipi_pll_10bit_98mhz_4lane()
{

	//Four Lane

	sensor_i2c_write(0x302A, 0x0004 );  			// vt_pix_clk_div
	sensor_i2c_write(0x302C, 0x0001 );           // vt_sys_clk_div
	sensor_i2c_write(0x302E, 0x0002 );           // pre_pll_clk_div
	sensor_i2c_write(0x3030, 0x000D);           // pll_multiplier
	sensor_i2c_write(0x3036, 0x0008);           // op_pix_clk_div
	sensor_i2c_write(0x3038, 0x0001 );           // op_sys_clk_div


	//Two lane
	//	          sensor_i2c_write(0x302A, 0x0004 );  			// vt_pix_clk_div
	//				sensor_i2c_write(0x302C, 0x0002 );           // vt_sys_clk_div
	//				sensor_i2c_write(0x302E, 0x0002 );           // pre_pll_clk_div
	//				sensor_i2c_write(0x3030, 0x0020);           // pll_multiplier
	//				sensor_i2c_write(0x3036, 0x0008);           // op_pix_clk_div
	//				sensor_i2c_write(0x3038, 0x0001 );           // op_sys_clk_div

}

static void ar0330_optm_v5_sequencer()
{
	uint32_t i;

	//OTPM V5 Sequencer

	msdelay(100);
	//	for(i = 0; i < 1000; i++); // Delay 100 ms


	sensor_i2c_write(0x3064, 0x1802);
	sensor_i2c_write(COLOR_MODE_GR2, 0x0001);
	sensor_i2c_write(0x31E0, 0x0703);
	sensor_i2c_write(0x306E, 0xFC10);

	//0x300e, 0x0010,
	sensor_i2c_write(0x30f0, 0x1200);
	sensor_i2c_write(COLOR_MODE_RED, 0x0000);
	sensor_i2c_write(0x30BA, 0x002C);
	sensor_i2c_write(0x30FE, 0x0080);
	sensor_i2c_write(0x31E0, 0x0000);
	//0x3ECE, 0x00FF,
	sensor_i2c_write(0x3ED0, 0xE4F6);
	sensor_i2c_write(0x3ED2, 0x0146);
	sensor_i2c_write(0x3ED4, 0x8F6C);
	sensor_i2c_write(0x3ED6, 0x66CC);
	sensor_i2c_write(0x3ED8, 0x8C42);
	sensor_i2c_write(0x3EDA, 0x8822);
	sensor_i2c_write(0x3EDC, 0x2222);
	sensor_i2c_write(0x3EDE, 0x22C0);
	sensor_i2c_write(0x3EE0, 0x1500);
	sensor_i2c_write(0x3EE6, 0x0080);
	sensor_i2c_write(0x3EE8, 0x2027);
	sensor_i2c_write(0x3EEA, 0x001D);
	sensor_i2c_write(0x3F06, 0x046A);

	sensor_i2c_write(0x301a, 0x10c8);


	sensor_i2c_write(0x3088, 0x8000);
	sensor_i2c_write(0x3086, 0x4A03);
	sensor_i2c_write(0x3086, 0x4316);
	sensor_i2c_write(0x3086, 0x0443);
	sensor_i2c_write(0x3086, 0x1645);
	sensor_i2c_write(0x3086, 0x4045);
	sensor_i2c_write(0x3086, 0x6017);
	sensor_i2c_write(0x3086, 0x2045);
	sensor_i2c_write(0x3086, 0x404B);
	sensor_i2c_write(0x3086, 0x1244);
	sensor_i2c_write(0x3086, 0x6134);
	sensor_i2c_write(0x3086, 0x4A31);
	sensor_i2c_write(0x3086, 0x4342);
	sensor_i2c_write(0x3086, 0x4560);
	sensor_i2c_write(0x3086, 0x2714);
	sensor_i2c_write(0x3086, 0x3DFF);
	sensor_i2c_write(0x3086, 0x3DFF);
	sensor_i2c_write(0x3086, 0x3DEA);
	sensor_i2c_write(0x3086, 0x2704);
	sensor_i2c_write(0x3086, 0x3D10);
	sensor_i2c_write(0x3086, 0x2705);
	sensor_i2c_write(0x3086, 0x3D10);
	sensor_i2c_write(0x3086, 0x2715);
	sensor_i2c_write(0x3086, 0x3527);
	sensor_i2c_write(0x3086, 0x053D);
	sensor_i2c_write(0x3086, 0x1045);
	sensor_i2c_write(0x3086, 0x4027);
	sensor_i2c_write(0x3086, 0x0427);
	sensor_i2c_write(0x3086, 0x143D);
	sensor_i2c_write(0x3086, 0xFF3D);
	sensor_i2c_write(0x3086, 0xFF3D);
	sensor_i2c_write(0x3086, 0xEA62);
	sensor_i2c_write(0x3086, 0x2728);
	sensor_i2c_write(0x3086, 0x3627);
	sensor_i2c_write(0x3086, 0x083D);
	sensor_i2c_write(0x3086, 0x6444);
	sensor_i2c_write(0x3086, 0x2C2C);
	sensor_i2c_write(0x3086, 0x2C2C);
	sensor_i2c_write(0x3086, 0x4B01);
	sensor_i2c_write(0x3086, 0x432D);
	sensor_i2c_write(0x3086, 0x4643);
	sensor_i2c_write(0x3086, 0x1647);
	sensor_i2c_write(0x3086, 0x435F);
	sensor_i2c_write(0x3086, 0x4F50);
	sensor_i2c_write(0x3086, 0x2604);
	sensor_i2c_write(0x3086, 0x2684);
	sensor_i2c_write(0x3086, 0x2027);
	sensor_i2c_write(0x3086, 0xFC53);
	sensor_i2c_write(0x3086, 0x0D5C);
	sensor_i2c_write(0x3086, 0x0D57);
	sensor_i2c_write(0x3086, 0x5417);
	sensor_i2c_write(0x3086, 0x0955);
	sensor_i2c_write(0x3086, 0x5649);
	sensor_i2c_write(0x3086, 0x5307);
	sensor_i2c_write(0x3086, 0x5302);
	sensor_i2c_write(0x3086, 0x4D28);
	sensor_i2c_write(0x3086, 0x6C4C);
	sensor_i2c_write(0x3086, 0x0928);
	sensor_i2c_write(0x3086, 0x2C28);
	sensor_i2c_write(0x3086, 0x294E);
	sensor_i2c_write(0x3086, 0x5C09);
	sensor_i2c_write(0x3086, 0x6045);
	sensor_i2c_write(0x3086, 0x0045);
	sensor_i2c_write(0x3086, 0x8026);
	sensor_i2c_write(0x3086, 0xA627);
	sensor_i2c_write(0x3086, 0xF817);
	sensor_i2c_write(0x3086, 0x0227);
	sensor_i2c_write(0x3086, 0xFA5C);
	sensor_i2c_write(0x3086, 0x0B17);
	sensor_i2c_write(0x3086, 0x1826);
	sensor_i2c_write(0x3086, 0xA25C);
	sensor_i2c_write(0x3086, 0x0317);
	sensor_i2c_write(0x3086, 0x4427);
	sensor_i2c_write(0x3086, 0xF25F);
	sensor_i2c_write(0x3086, 0x2809);
	sensor_i2c_write(0x3086, 0x1714);
	sensor_i2c_write(0x3086, 0x2808);
	sensor_i2c_write(0x3086, 0x1616);
	sensor_i2c_write(0x3086, 0x4D1A);
	sensor_i2c_write(0x3086, 0x2683);
	sensor_i2c_write(0x3086, 0x1616);
	sensor_i2c_write(0x3086, 0x27FA);
	sensor_i2c_write(0x3086, 0x45A0);
	sensor_i2c_write(0x3086, 0x1707);
	sensor_i2c_write(0x3086, 0x27FB);
	sensor_i2c_write(0x3086, 0x1729);
	sensor_i2c_write(0x3086, 0x4580);
	sensor_i2c_write(0x3086, 0x1708);
	sensor_i2c_write(0x3086, 0x27FA);
	sensor_i2c_write(0x3086, 0x1728);
	sensor_i2c_write(0x3086, 0x5D17);
	sensor_i2c_write(0x3086, 0x0E26);
	sensor_i2c_write(0x3086, 0x8153);
	sensor_i2c_write(0x3086, 0x0117);
	sensor_i2c_write(0x3086, 0xE653);
	sensor_i2c_write(0x3086, 0x0217);
	sensor_i2c_write(0x3086, 0x1026);
	sensor_i2c_write(0x3086, 0x8326);
	sensor_i2c_write(0x3086, 0x8248);
	sensor_i2c_write(0x3086, 0x4D4E);
	sensor_i2c_write(0x3086, 0x2809);
	sensor_i2c_write(0x3086, 0x4C0B);
	sensor_i2c_write(0x3086, 0x6017);
	sensor_i2c_write(0x3086, 0x2027);
	sensor_i2c_write(0x3086, 0xF217);
	sensor_i2c_write(0x3086, 0x535F);
	sensor_i2c_write(0x3086, 0x2808);
	sensor_i2c_write(0x3086, 0x164D);
	sensor_i2c_write(0x3086, 0x1A16);
	sensor_i2c_write(0x3086, 0x1627);
	sensor_i2c_write(0x3086, 0xFA26);
	sensor_i2c_write(0x3086, 0x035C);
	sensor_i2c_write(0x3086, 0x0145);
	sensor_i2c_write(0x3086, 0x4027);
	sensor_i2c_write(0x3086, 0x9817);
	sensor_i2c_write(0x3086, 0x2A4A);
	sensor_i2c_write(0x3086, 0x0A43);
	sensor_i2c_write(0x3086, 0x160B);
	sensor_i2c_write(0x3086, 0x4327);
	sensor_i2c_write(0x3086, 0x9C45);
	sensor_i2c_write(0x3086, 0x6017);
	sensor_i2c_write(0x3086, 0x0727);
	sensor_i2c_write(0x3086, 0x9D17);
	sensor_i2c_write(0x3086, 0x2545);
	sensor_i2c_write(0x3086, 0x4017);
	sensor_i2c_write(0x3086, 0x0827);
	sensor_i2c_write(0x3086, 0x985D);
	sensor_i2c_write(0x3086, 0x2645);
	sensor_i2c_write(0x3086, 0x5C01);
	sensor_i2c_write(0x3086, 0x4B17);
	sensor_i2c_write(0x3086, 0x0A28);
	sensor_i2c_write(0x3086, 0x0853);
	sensor_i2c_write(0x3086, 0x0D52);
	sensor_i2c_write(0x3086, 0x5112);
	sensor_i2c_write(0x3086, 0x4460);
	sensor_i2c_write(0x3086, 0x184A);
	sensor_i2c_write(0x3086, 0x0343);
	sensor_i2c_write(0x3086, 0x1604);
	sensor_i2c_write(0x3086, 0x4316);
	sensor_i2c_write(0x3086, 0x5843);
	sensor_i2c_write(0x3086, 0x1659);
	sensor_i2c_write(0x3086, 0x4316);
	sensor_i2c_write(0x3086, 0x5A43);
	sensor_i2c_write(0x3086, 0x165B);
	sensor_i2c_write(0x3086, 0x4345);
	sensor_i2c_write(0x3086, 0x4027);
	sensor_i2c_write(0x3086, 0x9C45);
	sensor_i2c_write(0x3086, 0x6017);
	sensor_i2c_write(0x3086, 0x0727);
	sensor_i2c_write(0x3086, 0x9D17);
	sensor_i2c_write(0x3086, 0x2545);
	sensor_i2c_write(0x3086, 0x4017);
	sensor_i2c_write(0x3086, 0x1027);
	sensor_i2c_write(0x3086, 0x9817);
	sensor_i2c_write(0x3086, 0x2022);
	sensor_i2c_write(0x3086, 0x4B12);
	sensor_i2c_write(0x3086, 0x442C);
	sensor_i2c_write(0x3086, 0x2C2C);
	sensor_i2c_write(0x3086, 0x2C00);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);

	//	sensor_i2c_write_bits(0x301A, 0x0004, 1);  //Enable Streaming
}




static void ar0330_sequencer_shortened()
{
	uint32_t i;
	//Sequencer length is 1014clocks/row.
	//sensor_i2c_write_bits(0x301A, 0x0004, 0);   //Disable Streaming
	msdelay(100);

	sensor_i2c_write(0x3088, 0x80BA); 			//0x80AA
	sensor_i2c_write(0x3086, 0x0253);
	//	sensor_i2c_write_bits(0x301A, 0x0004, 1);  	//Enable Streaming
}



static void mipi_optm_v5_sequencer()
{
	uint32_t i;

	//OTPM V5 Sequencer
	sensor_i2c_write_bits(0x301A, 0x0004, 0);  //Disable Streaming

	msdelay(100);

	sensor_i2c_write(0x3088, 0x8000);
	sensor_i2c_write(0x3086, 0x4A03);
	sensor_i2c_write(0x3086, 0x4316);
	sensor_i2c_write(0x3086, 0x0443);
	sensor_i2c_write(0x3086, 0x1645);
	sensor_i2c_write(0x3086, 0x4045);
	sensor_i2c_write(0x3086, 0x6017);
	sensor_i2c_write(0x3086, 0x2045);
	sensor_i2c_write(0x3086, 0x404B);
	sensor_i2c_write(0x3086, 0x1244);
	sensor_i2c_write(0x3086, 0x6134);
	sensor_i2c_write(0x3086, 0x4A31);
	sensor_i2c_write(0x3086, 0x4342);
	sensor_i2c_write(0x3086, 0x4560);
	sensor_i2c_write(0x3086, 0x2714);
	sensor_i2c_write(0x3086, 0x3DFF);
	sensor_i2c_write(0x3086, 0x3DFF);
	sensor_i2c_write(0x3086, 0x3DEA);
	sensor_i2c_write(0x3086, 0x2704);
	sensor_i2c_write(0x3086, 0x3D10);
	sensor_i2c_write(0x3086, 0x2705);
	sensor_i2c_write(0x3086, 0x3D10);
	sensor_i2c_write(0x3086, 0x2715);
	sensor_i2c_write(0x3086, 0x3527);
	sensor_i2c_write(0x3086, 0x053D);
	sensor_i2c_write(0x3086, 0x1045);
	sensor_i2c_write(0x3086, 0x4027);
	sensor_i2c_write(0x3086, 0x0427);
	sensor_i2c_write(0x3086, 0x143D);
	sensor_i2c_write(0x3086, 0xFF3D);
	sensor_i2c_write(0x3086, 0xFF3D);
	sensor_i2c_write(0x3086, 0xEA62);
	sensor_i2c_write(0x3086, 0x2728);
	sensor_i2c_write(0x3086, 0x3627);
	sensor_i2c_write(0x3086, 0x083D);
	sensor_i2c_write(0x3086, 0x6444);
	sensor_i2c_write(0x3086, 0x2C2C);
	sensor_i2c_write(0x3086, 0x2C2C);
	sensor_i2c_write(0x3086, 0x4B01);
	sensor_i2c_write(0x3086, 0x432D);
	sensor_i2c_write(0x3086, 0x4643);
	sensor_i2c_write(0x3086, 0x1647);
	sensor_i2c_write(0x3086, 0x435F);
	sensor_i2c_write(0x3086, 0x4F50);
	sensor_i2c_write(0x3086, 0x2604);
	sensor_i2c_write(0x3086, 0x2684);
	sensor_i2c_write(0x3086, 0x2027);
	sensor_i2c_write(0x3086, 0xFC53);
	sensor_i2c_write(0x3086, 0x0D5C);
	sensor_i2c_write(0x3086, 0x0D57);
	sensor_i2c_write(0x3086, 0x5417);
	sensor_i2c_write(0x3086, 0x0955);
	sensor_i2c_write(0x3086, 0x5649);
	sensor_i2c_write(0x3086, 0x5307);
	sensor_i2c_write(0x3086, 0x5302);
	sensor_i2c_write(0x3086, 0x4D28);
	sensor_i2c_write(0x3086, 0x6C4C);
	sensor_i2c_write(0x3086, 0x0928);
	sensor_i2c_write(0x3086, 0x2C28);
	sensor_i2c_write(0x3086, 0x294E);
	sensor_i2c_write(0x3086, 0x5C09);
	sensor_i2c_write(0x3086, 0x6045);
	sensor_i2c_write(0x3086, 0x0045);
	sensor_i2c_write(0x3086, 0x8026);
	sensor_i2c_write(0x3086, 0xA627);
	sensor_i2c_write(0x3086, 0xF817);
	sensor_i2c_write(0x3086, 0x0227);
	sensor_i2c_write(0x3086, 0xFA5C);
	sensor_i2c_write(0x3086, 0x0B17);
	sensor_i2c_write(0x3086, 0x1826);
	sensor_i2c_write(0x3086, 0xA25C);
	sensor_i2c_write(0x3086, 0x0317);
	sensor_i2c_write(0x3086, 0x4427);
	sensor_i2c_write(0x3086, 0xF25F);
	sensor_i2c_write(0x3086, 0x2809);
	sensor_i2c_write(0x3086, 0x1714);
	sensor_i2c_write(0x3086, 0x2808);
	sensor_i2c_write(0x3086, 0x1616);
	sensor_i2c_write(0x3086, 0x4D1A);
	sensor_i2c_write(0x3086, 0x2683);
	sensor_i2c_write(0x3086, 0x1616);
	sensor_i2c_write(0x3086, 0x27FA);
	sensor_i2c_write(0x3086, 0x45A0);
	sensor_i2c_write(0x3086, 0x1707);
	sensor_i2c_write(0x3086, 0x27FB);
	sensor_i2c_write(0x3086, 0x1729);
	sensor_i2c_write(0x3086, 0x4580);
	sensor_i2c_write(0x3086, 0x1708);
	sensor_i2c_write(0x3086, 0x27FA);
	sensor_i2c_write(0x3086, 0x1728);
	sensor_i2c_write(0x3086, 0x5D17);
	sensor_i2c_write(0x3086, 0x0E26);
	sensor_i2c_write(0x3086, 0x8153);
	sensor_i2c_write(0x3086, 0x0117);
	sensor_i2c_write(0x3086, 0xE653);
	sensor_i2c_write(0x3086, 0x0217);
	sensor_i2c_write(0x3086, 0x1026);
	sensor_i2c_write(0x3086, 0x8326);
	sensor_i2c_write(0x3086, 0x8248);
	sensor_i2c_write(0x3086, 0x4D4E);
	sensor_i2c_write(0x3086, 0x2809);
	sensor_i2c_write(0x3086, 0x4C0B);
	sensor_i2c_write(0x3086, 0x6017);
	sensor_i2c_write(0x3086, 0x2027);
	sensor_i2c_write(0x3086, 0xF217);
	sensor_i2c_write(0x3086, 0x535F);
	sensor_i2c_write(0x3086, 0x2808);
	sensor_i2c_write(0x3086, 0x164D);
	sensor_i2c_write(0x3086, 0x1A16);
	sensor_i2c_write(0x3086, 0x1627);
	sensor_i2c_write(0x3086, 0xFA26);
	sensor_i2c_write(0x3086, 0x035C);
	sensor_i2c_write(0x3086, 0x0145);
	sensor_i2c_write(0x3086, 0x4027);
	sensor_i2c_write(0x3086, 0x9817);
	sensor_i2c_write(0x3086, 0x2A4A);
	sensor_i2c_write(0x3086, 0x0A43);
	sensor_i2c_write(0x3086, 0x160B);
	sensor_i2c_write(0x3086, 0x4327);
	sensor_i2c_write(0x3086, 0x9C45);
	sensor_i2c_write(0x3086, 0x6017);
	sensor_i2c_write(0x3086, 0x0727);
	sensor_i2c_write(0x3086, 0x9D17);
	sensor_i2c_write(0x3086, 0x2545);
	sensor_i2c_write(0x3086, 0x4017);
	sensor_i2c_write(0x3086, 0x0827);
	sensor_i2c_write(0x3086, 0x985D);
	sensor_i2c_write(0x3086, 0x2645);
	sensor_i2c_write(0x3086, 0x5C01);
	sensor_i2c_write(0x3086, 0x4B17);
	sensor_i2c_write(0x3086, 0x0A28);
	sensor_i2c_write(0x3086, 0x0853);
	sensor_i2c_write(0x3086, 0x0D52);
	sensor_i2c_write(0x3086, 0x5112);
	sensor_i2c_write(0x3086, 0x4460);
	sensor_i2c_write(0x3086, 0x184A);
	sensor_i2c_write(0x3086, 0x0343);
	sensor_i2c_write(0x3086, 0x1604);
	sensor_i2c_write(0x3086, 0x4316);
	sensor_i2c_write(0x3086, 0x5843);
	sensor_i2c_write(0x3086, 0x1659);
	sensor_i2c_write(0x3086, 0x4316);
	sensor_i2c_write(0x3086, 0x5A43);
	sensor_i2c_write(0x3086, 0x165B);
	sensor_i2c_write(0x3086, 0x4345);
	sensor_i2c_write(0x3086, 0x4027);
	sensor_i2c_write(0x3086, 0x9C45);
	sensor_i2c_write(0x3086, 0x6017);
	sensor_i2c_write(0x3086, 0x0727);
	sensor_i2c_write(0x3086, 0x9D17);
	sensor_i2c_write(0x3086, 0x2545);
	sensor_i2c_write(0x3086, 0x4017);
	sensor_i2c_write(0x3086, 0x1027);
	sensor_i2c_write(0x3086, 0x9817);
	sensor_i2c_write(0x3086, 0x2022);
	sensor_i2c_write(0x3086, 0x4B12);
	sensor_i2c_write(0x3086, 0x442C);
	sensor_i2c_write(0x3086, 0x2C2C);
	sensor_i2c_write(0x3086, 0x2C00);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);
	sensor_i2c_write(0x3086, 0x0000);

	//	sensor_i2c_write_bits(0x301A, 0x0004, 1);  //Enable Streaming
}

static void mipi_sequencer_shortened()
{
	uint32_t i;
	//Sequencer length is 1014clocks/row.
	sensor_i2c_write_bits(0x301A, 0x0004, 0);   //Disable Streaming

	msdelay(1000);

	sensor_i2c_write(0x3088, 0x80BA); 			//0x80AA
	sensor_i2c_write(0x3086, 0x0253);
	//	sensor_i2c_write_bits(0x301A, 0x0004, 1);  	//Enable Streaming
}

void sensor_reset(void) {
	//	uint32_t i = 0;
	//	[Reset]
	//	STATE= Sensor Reset, 1
	////	MSS_GPIO_set_output(MSS_GPIO_0, 0);
	//	DELAY= 200
	///	for(i = 0; i < 150000; i++);
	//	STATE= Sensor Reset, 0
	///	MSS_GPIO_set_output(MSS_GPIO_0, 1);
	///	for(i = 0; i < 1500000; i++);
	//	FIELD_WR= RESET_REGISTER, 1
	//FIELD_WR= RESET_REGISTER, 0x10D8 //Register RESET_REGISTER
	//
	sensor_i2c_write(RESET_REGISTER, 0x01);
	// for(i = 0; i < 1500000; i++);
	sensor_i2c_write(RESET_REGISTER, 0x10D8);
}


void color_mode_select_none() {
	sensor_i2c_write(COLOR_MODE_RED, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_GR1, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_GR2, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_BLUE, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_SELECT, 0x00);
}

void color_mode_select_red() {

	sensor_i2c_write(COLOR_MODE_SELECT, 0x00);
	sensor_i2c_write(COLOR_MODE_RED, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_GR1, 0x0);
	sensor_i2c_write(COLOR_MODE_BLUE, 0x0);
	sensor_i2c_write(COLOR_MODE_GR2, 0x0);
	sensor_i2c_write(COLOR_MODE_SELECT, 0x01);
}

void color_mode_select_green() {

	sensor_i2c_write(COLOR_MODE_SELECT, 0x00);
	sensor_i2c_write(COLOR_MODE_RED, 0x0);
	sensor_i2c_write(COLOR_MODE_GR1, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_BLUE, 0x0);
	sensor_i2c_write(COLOR_MODE_GR2, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_SELECT, 0x01);
}

void color_mode_select_blue() {

	sensor_i2c_write(COLOR_MODE_SELECT, 0x00);
	sensor_i2c_write(COLOR_MODE_RED, 0x0);
	sensor_i2c_write(COLOR_MODE_GR1, 0x0);
	sensor_i2c_write(COLOR_MODE_BLUE, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_GR2, 0x0);
	sensor_i2c_write(COLOR_MODE_SELECT, 0x01);
}

void color_mode_bars() {

	sensor_i2c_write(COLOR_MODE_SELECT, 0x00);
	sensor_i2c_write(COLOR_MODE_RED, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_GR1, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_GR2, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_BLUE, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_SELECT, 0x02);
}

void color_mode_walking1s() {

	sensor_i2c_write(COLOR_MODE_SELECT, 0x00);
	sensor_i2c_write(COLOR_MODE_RED, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_GR1, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_GR2, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_BLUE, 0xFFFF);
	sensor_i2c_write(COLOR_MODE_SELECT, 0x100);
}

int mipi_1080_720_30fps_10bit_49mp_1lane()
{
	uint32_t i;
	uint16_t readdata;

	GPIO_set_output(&g_gpio_out, GPIO_8, 0u);
	msdelay(100);
	GPIO_set_output(&g_gpio_out, GPIO_8, 1u); // Bring camera out of reset

	I2C_init( sensor_i2c, COREI2C_BASE_ADDR, I2C_DEVICE_ADDR, I2C_PCLK_DIV_256 );

	if(hdmi_i2c_tx_write(I2C_MUX_ADDR,0,0x20) == I2C_SUCCESS)
	{
		printf("transaction successful\n");
	}

	//	if((readdata & 0xFFF) == 0)
	//		mipi_demo_init_4lane();

	sensor_i2c_write(0x3152, 0xA114);               // ?
	sensor_i2c_write(0x304a, 0x0070);                // ?
	msdelay(1000);           // should equate to 150,000 EXTCLK periods

	// reset
	sensor_i2c_write(0x301A, 0x0059);                // reset_register = Reset
	msdelay(100);
	sensor_i2c_write(0x301A, 0x0050);                // reset_register = Unlock
	msdelay(100);


	// Disable Streaming
	sensor_i2c_write_bits(0x301A, 0x0004, 0x0);

	mipi_pll_10bit_98mhz_4lane();
	msdelay(100);
	//sensor_i2c_write(0x31D2, 0x1A);

	sensor_i2c_write(0x3070, 1);
	sensor_i2c_write(0x3072, 0x5555);
	sensor_i2c_write(0x3074, 0x0000);
	sensor_i2c_write(0x3076, 0x0000);
	sensor_i2c_write(0x3078, 0x0000);


	// 1-lane MIPI Output
	sensor_i2c_write(0x31AE, 0x0204);//num of lanes
	sensor_i2c_write(0x31AC, 0x0808);    // data_format is 8-bit

	//Digiatl Gains
	sensor_i2c_write(0x3056, 0x80);
	sensor_i2c_write(0x3058, 0x80);
	sensor_i2c_write(0x305A, 0x80);
	sensor_i2c_write(0x305C, 0x80);
	sensor_i2c_write(0x305E, 0x80);

	//ARRAY READOUT SETTINGS
	sensor_i2c_write(0x3004, 450);		// X_ADDR_START 400
	sensor_i2c_write(0x3008, 2098);     // X_ADDR_END   2058
	sensor_i2c_write(0x3002, 100 );     // Y_ADDR_START 412
	sensor_i2c_write(0x3006, 851);     // Y_ADDR_END   1293

	//Sub-sampling
	sensor_i2c_write(0x30A2,1);   	   // X_ODD_INCREMENT
	sensor_i2c_write(0x30A6,1);   	   // Y_ODD_INCREMENT
	sensor_i2c_write_bits(0x3040, 0x1000, 0);  // Row Bin
	sensor_i2c_write_bits(0x3040, 0x2000, 0);  // Column Bin
	sensor_i2c_write_bits(0x3040, 0x0200, 0);  // Column SF Bin
	sensor_i2c_write(0x3ED4,0x8F6C);   // GrGb improved setting for non-binning
	sensor_i2c_write(0x3ED6,0x66CC);   // GrGb improved setting for non-binning

	sensor_i2c_write_bits(0x3040, 0xC000, 1);  // Vertical and Horizontal Flip

	//Frame-Timing
	sensor_i2c_write(0x300C, 1648);   	   // LINE_LENGTH_PCK           1648
	sensor_i2c_write(0x300A, 751 );   	   // FRAME_LENGTH_LINES        881
	sensor_i2c_write(0x3014, 0	 );   	   // FINE_INTEGRATION_TIME
	sensor_i2c_write(0x3012, 1648 );   	   // Coarse_Integration_Time
	sensor_i2c_write(0x3042, 0 );   	   // EXTRA_DELAY
	sensor_i2c_write_bits(0x30BA, 0x0040, 0);  // Digital_Ctrl_Adc_High_Speed

	//MIPI Timing Registers
	sensor_i2c_write(0x31B0, 40);
	sensor_i2c_write(0x31B2, 14);
	sensor_i2c_write(0x31B4, 0x5F77);
	sensor_i2c_write(0x31B6, 0x5299);
	sensor_i2c_write(0x31B8, 0x408E);
	sensor_i2c_write(0x31BA, 0x30C);
	sensor_i2c_write(0x31BC, 0x800A);
	sensor_i2c_write(0x31BE, 0x2003);

	mipi_optm_v5_sequencer();// Macro that loads sequencer also enables streaming
	mipi_sequencer_shortened();

	msdelay(1000);

	sensor_i2c_write_bits(0x301A, 0x0004, 1);  	//Enable Streaming
	for(i = 0; i < 50000; i++);
}

int mipi_1080_720_30fps_10bit_49mp_4lane()
{
	uint32_t i;
	uint16_t readdata;

	GPIO_set_output(&g_gpio_out, GPIO_8, 0u);
	msdelay(100);
	GPIO_set_output(&g_gpio_out, GPIO_8, 1u); // Bring camera out of reset

	I2C_init( sensor_i2c, COREI2C_BASE_ADDR, I2C_DEVICE_ADDR, I2C_PCLK_DIV_256 );

	if(hdmi_i2c_tx_write(I2C_MUX_ADDR,0,0x01) == I2C_SUCCESS)
	{
		printf("transaction successful\n");
		i=0;
	}

	//	if((readdata & 0xFFF) == 0)
	//		mipi_demo_init_4lane();

	sensor_i2c_write(0x3152, 0xA114);               // ?
	sensor_i2c_write(0x304a, 0x0070);                // ?
	msdelay(1000);           // should equate to 150,000 EXTCLK periods

	// reset
	sensor_i2c_write(0x301A, 0x0059);                // reset_register = Reset
	msdelay(100);
	sensor_i2c_write(0x301A, 0x0050);                // reset_register = Unlock
	msdelay(100);


	// Disable Streaming
	sensor_i2c_write_bits(0x301A, 0x0004, 0x0);

	mipi_pll_10bit_98mhz_4lane();
	msdelay(100);
	//sensor_i2c_write(0x31D2, 0x1A);

	sensor_i2c_write(0x3070, 0x0000);
	sensor_i2c_write(0x3072, 0x0000);
	sensor_i2c_write(0x3074, 0xFFFF);
	sensor_i2c_write(0x3076, 0x0000);
	sensor_i2c_write(0x3078, 0xFFFF);


	// 1-lane MIPI Output
	sensor_i2c_write(0x31AE, 0x0204);//num of lanes
	sensor_i2c_write(0x31AC, 0x0808);    // data_format is 8-bit

	//Digiatl Gains
	sensor_i2c_write(0x3056, 0x80);
	sensor_i2c_write(0x3058, 0x80);
	sensor_i2c_write(0x305A, 0x80);
	sensor_i2c_write(0x305C, 0x80);
	sensor_i2c_write(0x305E, 0x80);

	//ARRAY READOUT SETTINGS
	sensor_i2c_write(0x3004, 500);		// X_ADDR_START
	sensor_i2c_write(0x3008, 1779);     // X_ADDR_END
	sensor_i2c_write(0x3002, 411 );     // Y_ADDR_START
	sensor_i2c_write(0x3006, 1213);     // Y_ADDR_END

	//Sub-sampling
	sensor_i2c_write(0x30A2,1);   	   // X_ODD_INCREMENT
	sensor_i2c_write(0x30A6,1);   	   // Y_ODD_INCREMENT
	sensor_i2c_write_bits(0x3040, 0x1000, 0);  // Row Bin
	sensor_i2c_write_bits(0x3040, 0x2000, 0);  // Column Bin
	sensor_i2c_write_bits(0x3040, 0x0200, 0);  // Column SF Bin
	sensor_i2c_write(0x3ED4,0x8F6C);   // GrGb improved setting for non-binning
	sensor_i2c_write(0x3ED6,0x66CC);   // GrGb improved setting for non-binning

	sensor_i2c_write_bits(0x3040, 0xC000, 1);  // Vertical and Horizontal Flip

	//Frame-Timing
	sensor_i2c_write(0x300C, 1280);   	   // LINE_LENGTH_PCK
	sensor_i2c_write(0x300A, 812 );   	   // FRAME_LENGTH_LINES
	sensor_i2c_write(0x3014, 0	 );   	   // FINE_INTEGRATION_TIME
	sensor_i2c_write(0x3012, 800 );   	   // Coarse_Integration_Time
	sensor_i2c_write(0x3042, 0 );   	   // EXTRA_DELAY
	sensor_i2c_write_bits(0x30BA, 0x0040, 0);  // Digital_Ctrl_Adc_High_Speed

	//MIPI Timing Registers
	sensor_i2c_write(0x31B0, 40);
	sensor_i2c_write(0x31B2, 14);
	sensor_i2c_write(0x31B4, 0x5F77);
	sensor_i2c_write(0x31B6, 0x5299);
	sensor_i2c_write(0x31B8, 0x408E);
	sensor_i2c_write(0x31BA, 0x30C);
	sensor_i2c_write(0x31BC, 0x800A);
	sensor_i2c_write(0x31BE, 0x2003);

	mipi_optm_v5_sequencer();// Macro that loads sequencer also enables streaming
	mipi_sequencer_shortened();

	msdelay(1000);

	sensor_i2c_write_bits(0x301A, 0x0004, 1);  	//Enable Streaming
	for(i = 0; i < 50000; i++);
}
